@@ -353,6 +353,16 @@ class PrintSitePlugin(BasePlugin):
                 .add_javascript_variables(html, self.print_page, config)
             )
 
+        # Compatibility with https://github.com/g-provost/lightgallery-markdown
+        # This plugin insert link hrefs with double dashes, f.e.
+        # <link href="//assets/css/somecss.css">
+        # Details https://github.com/timvink/mkdocs-print-site-plugin/issues/68
+        htmls = html.split("</head>")
+        base_url = "../" if config.get("use_directory_urls") else ""
+        htmls[0] = htmls[0].replace("href=\"//", f"href=\"{base_url}")
+        htmls[0] = htmls[0].replace("src=\"//", f"src=\"{base_url}")
+        html = "</head>".join(htmls)
+
         # Determine calls to required javascript functions
         js_calls = "remove_material_navigation();"
         js_calls += "remove_mkdocs_theme_navigation();"
